;; Generated package description from vc-got.el  -*- no-byte-compile: t -*-
(define-package "vc-got" "1.1.1.0.20220528.153539" "VC backend for Game of Trees VCS" '((emacs "25.1")) :commit "d009a36e0933bafedec30516e7293fb15e84dd19" :authors '(("Omar Polo" . "op@omarpolo.com") ("Timo Myyrä" . "timo.myyra@bittivirhe.fi")) :maintainer '("Omar Polo" . "op@omarpolo.com") :keywords '("vc" "tools") :url "https://projects.omarpolo.com/vc-got.html")
